/*
 * Access control functions.
 *
 * Copyright (C) 2019 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "access.h"

int access_can_read(user_t user, struct ext2_inode *inode)
{
  /* NOTE: Could use a generic function for properly testing access.
     NOTE: For example, this does not permit multiple groups. */

  return ((inode->i_uid == user.uid) && (inode->i_mode & LINUX_S_IRUSR)) ||
         ((inode->i_gid == user.gid) && (inode->i_mode & LINUX_S_IRGRP)) ||
         (inode->i_mode & LINUX_S_IROTH);
}

int access_can_write(user_t user, struct ext2_inode *inode)
{
  /* NOTE: Could use a generic function for properly testing access.
     NOTE: For example, this does not permit multiple groups. */

  return ((inode->i_uid == user.uid) && (inode->i_mode & LINUX_S_IWUSR)) ||
         ((inode->i_gid == user.gid) && (inode->i_mode & LINUX_S_IWGRP)) ||
         (inode->i_mode & LINUX_S_IWOTH);
}
